from django.http import JsonResponse
from ks_response.response import StandardResponse, ReturnResponse


class DjangoJsonResponse(object):

    @staticmethod
    def __generate_standard_response(config_response: ReturnResponse, msg=None, data=None):
        msg = msg if msg is not None else config_response.response_message
        return DjangoJsonResponse.__get_response_object(
            DjangoJsonResponse.__generate_response(config_response.response_code, msg, data))

    @staticmethod
    def __generate_response(response_code, response_message, data=None):
        response_obj = ReturnResponse(response_code=response_code, response_message=response_message)
        return DjangoJsonResponse.__get_json_response(response_obj, response_data=data)

    @staticmethod
    def get_ok_response(msg=None, response_data=None):
        return DjangoJsonResponse.__generate_standard_response(StandardResponse.OK, msg, response_data)

    @staticmethod
    def get_not_exist_error_response(msg=None, response_data=None):
        return DjangoJsonResponse.__generate_standard_response(StandardResponse.OBJECT_NOT_EXIST, msg, response_data)

    @staticmethod
    def get_method_error_response(msg=None, response_data=None):
        return DjangoJsonResponse.__generate_standard_response(StandardResponse.METHOD_ERROR, msg, response_data)

    @staticmethod
    def get_parameter_required_response(msg=None, response_data=None):
        return DjangoJsonResponse.__generate_standard_response(StandardResponse.PARAMETER_REQUIRED, msg, response_data)

    @staticmethod
    def get_authentication_error_response(msg=None, response_data=None):
        return DjangoJsonResponse.__generate_standard_response(StandardResponse.AUTHENTICATION, msg, response_data)

    @staticmethod
    def get_not_found_method_error_response(msg=None, response_data=None):
        return DjangoJsonResponse.__generate_standard_response(StandardResponse.NOT_FOUND_METHOD, msg, response_data)

    @staticmethod
    def get_internal_error_response(msg=None, response_data=None):
        return DjangoJsonResponse.__generate_standard_response(StandardResponse.INTERNAL_ERROR, msg, response_data)

    @staticmethod
    def __get_json_response(response_obj: ReturnResponse, response_data: object = None) -> object:
        return {'response_message': response_obj.response_message,
                'response_code': response_obj.response_code,
                'response_data': response_data}

    @staticmethod
    def __get_response_object(response_json):
        response = JsonResponse(response_json, safe=False)
        response["Access-Control-Allow-Origin"] = "*"
        response["Access-Control-Allow-Methods"] = "POST, GET"
        response["Access-Control-Max-Age"] = "1000"
        response["Access-Control-Allow-Headers"] = "*"
        return response
